#include "dicelist.h"
#include "dicepicker.h"

#include <QWidget>
#include <QVBoxLayout>
#include <QString>
#include <QDataStream>
#include <KLocale>
#include <KMessageBox>
#include <KTextEdit>

#include <QTextStream>

DiceList::DiceList(int minimum, int maximum, QWidget* parent)
		: QVBoxLayout(parent), minimumDices(minimum), maximumDices(maximum), dicePickerDialog(0)
{
	for(int count  = minimum; count > 0; --count)
		addDiceDefault();
}

void DiceList::addDice(AbstractDice* dice)
{
	diceList.append(dice);
	addWidget(dice);
	connect(dice, SIGNAL(diceRolled(QString)), this, SIGNAL(diceRolled(QString)));
	connect(dice, SIGNAL(deleteMe()), this, SLOT(removeDice()));
	enableRemove();
}

void DiceList::showDiceDialog()
{
	if(dicePickerDialog == 0)
		dicePickerDialog = new DicePicker;
	dicePickerDialog->show();
}

void DiceList::removeDice()
{
	if (diceList.count() > minimumDices)
	{
		AbstractDice* dice = qobject_cast<AbstractDice*>(sender());
		removeDice(dice);
	}
	enableRemove();
}

void DiceList::removeDice(AbstractDice* dice)
{
	int i = diceList.indexOf(dice);
	delete diceList.takeAt(i);
	emit diceRemoved();
}

void DiceList::removeAll()
{
	foreach(AbstractDice* dice, diceList)
		removeDice(dice);
}

void DiceList::enableRemove()
{
	if(diceList.count() > minimumDices)
	{
		foreach(AbstractDice* dice, diceList)
			dice->setDeleteEnabled(true);
	}
	else
	{
		foreach(AbstractDice* dice, diceList)
			dice->setDeleteEnabled(false);
	}
}

void DiceList::save(QDataStream& stream)
{
	stream << qint32(diceList.count());
	foreach(AbstractDice* dice, diceList)
		dice->save(stream);
}

void DiceList::open(QDataStream& stream)
{
	removeAll();
	qint32 numberDice;
	stream >> numberDice;
	for(int c = 0;c < numberDice; c++)
	{
		qint32 i;
		stream >> i;

		if (i == Custem)
			addDiceDefault();
		else if (i == D20)
			addDiceD20();
		else if (i == Attack)
			addDiceAttack();
		else if (i == Stats)
			addDiceStats();
		else if (i == WOD)
			addDiceWOD();
		else if (i == DLabel)
			addDiceLabel();
		else
		{
			break;
		}
		diceList[c]->open(stream);
	}
}
