#ifndef DICELIST_H
#define DICELIST_H

#include "dice.h"
#include <QVBoxLayout>

class QWidget;
class QDataStream;
class KTextEdit;
class DicePicker;

class DiceList : public QVBoxLayout
{
	Q_OBJECT
public:
	DiceList(int minimum = 1, int maximum = 20, QWidget* parent = 0);

public slots:
//	void addResults(QString result);
	void addDice(AbstractDice* dice);
	void showDiceDialog();
	void removeDice();
	void removeDice(AbstractDice* dice);
	void removeAll();

	/**
	 * Sets the dice in the DiceList to be disabled or enabled dependent on how many dice are present
	 * and the minimum allowed dice to ensure the DiceList always has the minimum number od dice present.
	 */
	void enableRemove();

	void open(QDataStream& stream);
	void save(QDataStream& stream);

	void addDiceDefault() { addDice(new CustemDice); }
	void addDiceD20() { addDice(new D20Dice); }
	void addDiceAttack() { addDice(new AttackDice); }
	void addDiceStats() { addDice(new StatsDice); }
	void addDiceWOD() { addDice(new WODDice); }
	void addDiceLabel() { addDice(new LabelDice); }

signals:
	void diceRolled(QString);
	void diceRemoved();

private:
	int minimumDices;
	int maximumDices;
	QList<AbstractDice*> diceList;
	KTextEdit* results;
	DicePicker* dicePickerDialog;
};

#endif // DICELIST_H
